@@ -222,6 +222,12 @@ int    b_print(int argc, char *argv[], Shbltin_t *context)
 			rflag = 1;
 			break;
 		case 'u':
+			if(opt_info.arg[0]=='p' && opt_info.arg[1]==0)
+			{
+				fd = sh.coutpipe;
+				msg = e_query;
+				break;
+			}
 			fd = (int)strtol(opt_info.arg,&opt_info.arg,10);
 			if(*opt_info.arg)
 				fd = -1;
